@@ -13,8 +13,8 @@
 
 ;; Package-Requires: ((emacs "26.1"))
 
-;; Package-Version: 20251021.1619
-;; Package-Revision: 7f82d0758130
+;; Package-Version: 20251102.647
+;; Package-Revision: 14baf0c00b6c
 ;; Keywords: data, extensions
 ;; URL: https://github.com/tbanel/orgaggregate/blob/master/README.org
 
@@ -1998,6 +1998,16 @@ Note:
       post))
     (orgtbl-aggregate--table-recalculate content formula)))
 
+(defun orgtbl-aggregate--alist-get-remove (key alist)
+  "A variant of alist-get which removes an entry once read.
+ALIST is a list of pairs (key . value).
+Search ALIST for a KEY. If found, replace the key in (key . value)
+by nil, and return value. If nothing is found, return nil."
+  (let ((x (assq key alist)))
+    (when x
+      (setcar x nil)
+      (cdr x))))
+
 ;; This variable contains history of user entered
 ;; :cols and :cond parameters, so that they can be entered
 ;; again or edited
@@ -2136,7 +2146,7 @@ amended by the user."
 
       (setq table
             (orgtbl-aggregate--wizard-query-table
-             (alist-get :table oldline)))
+             (orgtbl-aggregate--alist-get-remove :table oldline)))
 
       (setq headerlist
             (orgtbl-aggregate--get-header-table table))
@@ -2164,7 +2174,7 @@ means:
       (setq precompute
             (read-string
              "Formulas for additional input columns (optional): "
-             (alist-get :precompute oldline)
+             (orgtbl-aggregate--alist-get-remove :precompute oldline)
              'orgtbl-aggregate-history-cols))
 
       (unless (eq (length precompute) 0)
@@ -2202,7 +2212,7 @@ Each target column may be followed optionally by semicolon separated parameters:
              "\"" "'"
              (read-string
               "Target columns & formulas: "
-              (alist-get :cols oldline)
+              (orgtbl-aggregate--alist-get-remove :cols oldline)
               'orgtbl-aggregate-history-cols)))
 
       (orgtbl-aggregate--display-help
@@ -2219,7 +2229,7 @@ Lisp function, lambda, or Babel block to filter out rows.
       (setq aggcond
             (read-string
              "Row filter (optional): "
-             (alist-get :cond oldline)
+             (orgtbl-aggregate--alist-get-remove :cond oldline)
              'orgtbl-aggregate-history-cols))
 
       (orgtbl-aggregate--display-help "* Output horizontal separators level
@@ -2234,7 +2244,8 @@ The columns considered are the sorted ones.")
              '("0" "1" "2" "3")
              nil
              'confirm
-             (orgtbl-aggregate--cell-to-string (alist-get :hline oldline))))
+             (orgtbl-aggregate--cell-to-string
+              (orgtbl-aggregate--alist-get-remove :hline oldline))))
 
       (orgtbl-aggregate--display-help "* Post-process
 The output aggregated table may be post-processed prior to printing it
@@ -2248,7 +2259,7 @@ The processor may be a Lisp function, a lambda, or a Babel block.
       (setq postprocess
             (read-string
              "Post process (optional): "
-             (alist-get :post oldline)
+             (orgtbl-aggregate--alist-get-remove :post oldline)
              'orgtbl-aggregate-history-cols))
       )
 
@@ -2267,7 +2278,7 @@ The processor may be a Lisp function, a lambda, or a Babel block.
       (nconc params `(:post ,postprocess)))
     (cl-loop
      for pair in oldline
-     unless (memq (car pair) '(:table :precompute :cols :cond :hline :post))
+     if (car pair)
      do (nconc params `(,(car pair) ,(cdr pair))))
     params))
 
@@ -2494,7 +2505,7 @@ amended by the user."
 
       (setq table
             (orgtbl-aggregate--wizard-query-table
-             (alist-get :table oldline)))
+             (orgtbl-aggregate--alist-get-remove :table oldline)))
 
       (setq headerlist
             (orgtbl-aggregate--get-header-table table))
@@ -2517,7 +2528,7 @@ in the same order.
              "\"" "'"
              (read-string
               "Target columns & formulas: "
-              (alist-get :cols oldline)
+              (orgtbl-aggregate--alist-get-remove :cols oldline)
               'orgtbl-aggregate-history-cols)))
 
       (orgtbl-aggregate--display-help
@@ -2535,7 +2546,7 @@ Lisp function, lambda, or Babel block to filter out rows.
       (setq aggcond
             (read-string
              "Row filter (optional): "
-             (alist-get :cond oldline)
+             (orgtbl-aggregate--alist-get-remove :cond oldline)
              'orgtbl-aggregate-history-cols))
 
       (orgtbl-aggregate--display-help
@@ -2552,7 +2563,7 @@ The processor may be a Lisp function, a lambda, or a Babel block.
       (setq postprocess
             (read-string
              "Post process (optional): "
-             (alist-get :post oldline)
+             (orgtbl-aggregate--alist-get-remove :post oldline)
              'orgtbl-aggregate-history-cols))
       )
 
@@ -2567,7 +2578,7 @@ The processor may be a Lisp function, a lambda, or a Babel block.
       (nconc params `(:post ,postprocess)))
     (cl-loop
      for pair in oldline
-     unless (memq (car pair) '(:table :cols :cond :post))
+     if (car pair)
      do (nconc params `(,(car pair) ,(cdr pair))))
     params))
 
